@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-25'; # DATE
+our $DATE = '2023-12-11'; # DATE
 our $DIST = 'App-CPANStreaks'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %SPEC;
 
@@ -56,6 +56,9 @@ $SPEC{cpan_streaks} = {
             schema => 'bool*',
             default => 1,
         },
+        min_len => {
+            schema => 'posint*',
+        },
     },
 };
 sub cpan_streaks {
@@ -106,6 +109,7 @@ sub cpan_streaks {
         my $rows = Set::Streak::gen_longest_streaks_table(
             sets => \@sets,
             exclude_broken => $args{exclude_broken},
+            min_len => $args{min_len},
         );
         for my $row (@$rows) {
             $row->{start_date} = $period_names[ $row->{start} ];
@@ -140,7 +144,7 @@ App::CPANStreaks - Calculate various CPAN streaks
 
 =head1 VERSION
 
-This document describes version 0.002 of App::CPANStreaks (from Perl distribution App-CPANStreaks), released on 2023-11-25.
+This document describes version 0.003 of App::CPANStreaks (from Perl distribution App-CPANStreaks), released on 2023-12-11.
 
 =head1 DESCRIPTION
 
@@ -173,6 +177,10 @@ Only calculate streaks for certain authors.
 
 (No description)
 
+=item * B<min_len> => I<posint>
+
+(No description)
+
 =item * B<table> => I<str>
 
 (No description)
